fn burst_limit(rate: EndpointRate, share: f64) -> f64Expand description
At least one, so an endpoint whose capacity is a couple of requests still gets one through at the floor.
fn burst_limit(rate: EndpointRate, share: f64) -> f64At least one, so an endpoint whose capacity is a couple of requests still gets one through at the floor.