pub(super) fn endpoint_rate(endpoint: SuotarEndpoint) -> Option<EndpointRate>Expand description
The rate an endpoint is limited to, or None for one that is not limited.
pub(super) fn endpoint_rate(endpoint: SuotarEndpoint) -> Option<EndpointRate>The rate an endpoint is limited to, or None for one that is not limited.